summaryrefslogtreecommitdiff
path: root/NxWidgets/libnxwidgets/src/ccallback.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'NxWidgets/libnxwidgets/src/ccallback.cxx')
-rw-r--r--NxWidgets/libnxwidgets/src/ccallback.cxx12
1 files changed, 6 insertions, 6 deletions
diff --git a/NxWidgets/libnxwidgets/src/ccallback.cxx b/NxWidgets/libnxwidgets/src/ccallback.cxx
index cec7ea1bf..46108acf3 100644
--- a/NxWidgets/libnxwidgets/src/ccallback.cxx
+++ b/NxWidgets/libnxwidgets/src/ccallback.cxx
@@ -45,7 +45,7 @@
#include <debug.h>
#ifdef CONFIG_NXTERM_NXKBDIN
-# include <nuttx/nx/nxconsole.h>
+# include <nuttx/nx/nxterm.h>
#endif
#include "cwidgetcontrol.hxx"
@@ -88,7 +88,7 @@ CCallback::CCallback(CWidgetControl *widgetControl)
// Keyboard input is initially direct to the widgets within the window
#ifdef CONFIG_NXTERM_NXKBDIN
- m_nxconsole = (NXCONSOLE)0;
+ m_nxterm = (NXTERM)0;
#endif
}
@@ -206,15 +206,15 @@ void CCallback::newKeyboardEvent(NXHANDLE hwnd, uint8_t nCh,
CCallback *This = (CCallback *)arg;
// Is NX keyboard input being directed to the widgets within the window
// (default) OR is NX keyboard input being re-directed to an NxConsole
// driver?
#ifdef CONFIG_NXTERM_NXKBDIN
- if (This->m_nxconsole)
+ if (This->m_nxterm)
{
- // Keyboard input is going to an NxConsole
+ // Keyboard input is going to an NxTerm
- nxcon_kbdin(This->m_nxconsole, str, nCh);
+ nxcon_kbdin(This->m_nxterm, str, nCh);
}
else
#endif
@@ -206,15 +206,15 @@ void CCallback::newKeyboardEvent(NXHANDLE hwnd, uint8_t nCh,
CCallback *This = (CCallback *)arg;
// Is NX keyboard input being directed to the widgets within the window
- // (default) OR is NX keyboard input being re-directed to an NxConsole
+ // (default) OR is NX keyboard input being re-directed to an NxTerm
// driver?
#ifdef CONFIG_NXTERM_NXKBDIN